@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """pytest fixtures for testing cookiecutter's replay feature."""
-
 import pytest
 
 
@@ -9,11 +6,11 @@ import pytest
 def context():
     """Fixture to return a valid context as known from a cookiecutter.json."""
     return {
-        u'cookiecutter': {
-            u'email': u'raphael@hackebrot.de',
-            u'full_name': u'Raphael Pierzina',
-            u'github_username': u'hackebrot',
-            u'version': u'0.1.0',
+        'cookiecutter': {
+            'email': 'raphael@hackebrot.de',
+            'full_name': 'Raphael Pierzina',
+            'github_username': 'hackebrot',
+            'version': '0.1.0',
         }
     }
 
