@@ -5,6 +5,7 @@ Test formerly known from a unittest residing in test_generate.py named
 TestOutputFolder.test_output_folder
 """
 import os
+from pathlib import Path
 
 import pytest
 
@@ -31,12 +32,13 @@ def test_output_folder():
 
     something = """Hi!
 My name is Audrey Greenfeld.
-It is 2014."""
-    something2 = open('output_folder/something.txt').read()
+It is 2014.
+"""
+    something2 = Path('output_folder/something.txt').read_text()
     assert something == something2
 
-    in_folder = "The color is green and the letter is D."
-    in_folder2 = open('output_folder/folder/in_folder.txt').read()
+    in_folder = "The color is green and the letter is D.\n"
+    in_folder2 = Path('output_folder/folder/in_folder.txt').read_text()
     assert in_folder == in_folder2
 
     assert os.path.isdir('output_folder/im_a.dir')
