@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-
 """Testing invalid cookiecutter template repositories."""
-
 import pytest
 
-from cookiecutter import main, exceptions
+from cookiecutter import exceptions, main
 
 
 def test_should_raise_error_if_repo_does_not_exist():
